@@ -74,7 +74,7 @@ def addCanIUsePanels(doc):
             .caniuse-status > .support > span { padding: 0.2em 0; display: block; display: table; }
             .caniuse-status > .support > span.partial { color: #666666; filter: grayscale(50%); }
             .caniuse-status > .support > span.no { color: #CCCCCC; filter: grayscale(100%); }
-            .canisue-status > .support > span.no::before { opacity: 0.5; }
+            .caniuse-status > .support > span.no::before { opacity: 0.5; }
             .caniuse-status > .support > span:first-of-type { padding-top: 0.5em; }
             .caniuse-status > .support > span > span { padding: 0 0.5em; display: table-cell; vertical-align: top; }
             .caniuse-status > .support > span > span:first-child { width: 100%; }
