@@ -470,93 +470,7 @@ def fillInterDocumentReferenceFromSpecref(doc, el, spec, section):
     removeAttr(el, 'data-link-spec', 'spec-section')
 
 
-def fillAttributeInfoSpans(doc):
-    # Auto-add <span attribute-info> to <dt><dfn> when it's an attribute or dict-member.
-    for dt in findAll("dt", doc):
-        if find("span[data-attribute-info]", dt) is not None:
-            # Already has one, no need to do any work here
-            continue
-        dfn = find("dfn", dt)
-        if dfn is None:
-            continue
-        dfnType = dfn.get("data-dfn-type")
-        if dfnType == "attribute":
-            attrName = "data-attribute-info"
-        elif dfnType == "dict-member":
-            attrName = "data-dict-member-info"
-        else:
-            continue
-        spanFor = config.firstLinkTextFromElement(dfn)
-        if spanFor is None:
-            continue
-        # Internal slots (denoted by [[foo]] naming scheme) don't have attribute info
-        if spanFor.startswith("[["):
-            continue
-        if dfn.get("data-dfn-for"):
-            spanFor = dfn.get("data-dfn-for") + "/" + spanFor
-        # If there's whitespace after the dfn, clear it out
-        if emptyText(dfn.tail, wsAllowed=True):
-            dfn.tail = None
-        insertAfter(dfn,
-                    ", ",
-                    E.span({attrName:"", "for":spanFor}))
 
-    for el in findAll("span[data-attribute-info], span[data-dict-member-info]", doc):
-        if el.get('data-attribute-info') is not None:
-            refType = "attribute"
-        else:
-            refType = "dict-member"
-        if (el.text is None or el.text.strip() == '') and len(el) == 0:
-            referencedAttribute = el.get("for")
-            if referencedAttribute is None or referencedAttribute == "":
-                die("Missing for reference in attribute info span.", el=el)
-                continue
-            if "/" in referencedAttribute:
-                interface, referencedAttribute = referencedAttribute.split("/")
-                target = findAll('a[data-link-type={2}][data-lt="{0}"][data-link-for="{1}"]'.format(referencedAttribute, interface, refType), doc)
-            else:
-                target = findAll('a[data-link-type={1}][data-lt="{0}"]'.format(referencedAttribute, refType), doc)
-            if len(target) == 0:
-                die("Couldn't find target {1} '{0}':\n{2}", referencedAttribute, refType, outerHTML(el), el=el)
-                continue
-            elif len(target) > 1:
-                die("Multiple potential target {1}s '{0}':\n{2}", referencedAttribute, refType, outerHTML(el), el=el)
-                continue
-            target = target[0]
-            datatype = target.get("data-type").strip()
-            default = target.get("data-default")
-            decorations = []
-            if target.get("data-readonly") is not None:
-                decorations.append(", readonly")
-            if datatype[-1] == "?":
-                decorations.append(", nullable")
-                datatype = datatype[:-1]
-            if default is not None:
-                decorations.append(", defaulting to ")
-                decorations.append(E.code(default))
-            if datatype[0] == "(":
-                # Union type
-                # TODO(Nov 2015): actually handle this properly, don't have time to think through it right now.
-                appendChild(el,
-                            " of type ",
-                            E.code({"class":"idl-code"}, datatype),
-                            *decorations)
-            elif re.match(r"(\w+)<(\w+)>", datatype):
-                # Sequence type
-                match = re.match(r"(\w+)<(\w+)>", datatype)
-                appendChild(el,
-                            " of type ",
-                            match.group(1),
-                            "<",
-                            E.a({"data-link-type":"idl-name"}, match.group(2)),
-                            ">",
-                            *decorations)
-            else:
-                # Everything else
-                appendChild(el,
-                            " of type ",
-                            E.a({"data-link-type":"idl-name"}, datatype),
-                            *decorations)
 
 
 def processDfns(doc):
